==> console-container-v2.3.3-4.tar.gz: package/ReducerRegistry/ReducerRegistry.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.applyReducerHash = applyReducerHash;
exports.dispatchActionsToStore = dispatchActionsToStore;
exports["default"] = exports.reduxRegistry = exports.ReducerRegistry = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _redux = require("redux");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function applyReducerHash(reducerHash) {
  var initialState = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return function () {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
    var action = arguments.length > 1 ? arguments[1] : undefined;

    if (Object.prototype.hasOwnProperty.call(reducerHash, action.type)) {
      return reducerHash[action.type](state, action);
    }

    return state;
  };
}

function dispatchActionsToStore(actions, store) {
  return Object.keys(actions).reduce(function (acc, curr) {
    return _objectSpread(_objectSpread({}, acc), {}, (0, _defineProperty2["default"])({}, curr, function () {
      return store && store.dispatch(actions[curr].apply(actions, arguments));
    }));
  }, {});
}
/**
 * Class used to added reducers to the store during runtime.
 *
 * http://nicolasgallagher.com/redux-modules-and-code-splitting/
 */


var ReducerRegistry = /*#__PURE__*/function () {
  function ReducerRegistry() {
    var initState = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var middlewares = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    var composeEnhancersDefault = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : _redux.compose;
    (0, _classCallCheck2["default"])(this, ReducerRegistry);
    var composeEnhancers = window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ || composeEnhancersDefault;
    this.store = (0, _redux.createStore)(function () {
      var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initState;
      return state;
    }, initState, composeEnhancers(_redux.applyMiddleware.apply(void 0, (0, _toConsumableArray2["default"])(middlewares))));
    this.reducers = {};
  }

  (0, _createClass2["default"])(ReducerRegistry, [{
    key: "getStore",
    value: function getStore() {
      return this.store;
    }
    /**
     * Adds new reducers to the store
     *
     * @param newReducers the object of new reducers.
     */

  }, {
    key: "register",
    value: function register(newReducers) {
      var _this = this;

      this.reducers = _objectSpread(_objectSpread({}, this.reducers), newReducers);
      this.store.replaceReducer((0, _redux.combineReducers)(_objectSpread({}, this.reducers)));
      return function () {
        _this.reducers = Object.entries(_this.reducers).filter(function (reducer) {
          return !Object.keys(newReducers).includes(reducer);
        }).reduce(function (acc, _ref) {
          var _ref2 = (0, _slicedToArray2["default"])(_ref, 2),
              key = _ref2[0],
              val = _ref2[1];

          return _objectSpread(_objectSpread({}, acc), {}, (0, _defineProperty2["default"])({}, key, val));
        }, {});

        _this.store.replaceReducer((0, _redux.combineReducers)(_objectSpread({}, _this.reducers)));
      };
    }
  }]);
  return ReducerRegistry;
}();

exports.ReducerRegistry = ReducerRegistry;
var reduxRegistry = new ReducerRegistry();
exports.reduxRegistry = reduxRegistry;
var _default = ReducerRegistry;
exports["default"] = _default;

==> console-container-v2.3.9-2.tar.gz: package/ReducerRegistry/ReducerRegistry.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.applyReducerHash = applyReducerHash;
exports.dispatchActionsToStore = dispatchActionsToStore;
exports["default"] = exports.reduxRegistry = exports.ReducerRegistry = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _redux = require("redux");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function applyReducerHash(reducerHash) {
  var initialState = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return function () {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
    var action = arguments.length > 1 ? arguments[1] : undefined;

    if (Object.prototype.hasOwnProperty.call(reducerHash, action.type)) {
      return reducerHash[action.type](state, action);
    }

    return state;
  };
}

function dispatchActionsToStore(actions, store) {
  return Object.keys(actions).reduce(function (acc, curr) {
    return _objectSpread(_objectSpread({}, acc), {}, (0, _defineProperty2["default"])({}, curr, function () {
      return store && store.dispatch(actions[curr].apply(actions, arguments));
    }));
  }, {});
}
/**
 * Class used to added reducers to the store during runtime.
 *
 * http://nicolasgallagher.com/redux-modules-and-code-splitting/
 */


var ReducerRegistry = /*#__PURE__*/function () {
  function ReducerRegistry() {
    var initState = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var middlewares = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    var composeEnhancersDefault = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : _redux.compose;
    (0, _classCallCheck2["default"])(this, ReducerRegistry);
    var composeEnhancers = typeof window !== 'undefined' && window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ || composeEnhancersDefault;
    this.store = (0, _redux.createStore)(function () {
      var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initState;
      return state;
    }, initState, composeEnhancers(_redux.applyMiddleware.apply(void 0, (0, _toConsumableArray2["default"])(middlewares))));
    this.reducers = {};
  }

  (0, _createClass2["default"])(ReducerRegistry, [{
    key: "getStore",
    value: function getStore() {
      return this.store;
    }
    /**
     * Adds new reducers to the store
     *
     * @param newReducers the object of new reducers.
     */

  }, {
    key: "register",
    value: function register(newReducers) {
      var _this = this;

      this.reducers = _objectSpread(_objectSpread({}, this.reducers), newReducers);
      this.store.replaceReducer((0, _redux.combineReducers)(_objectSpread({}, this.reducers)));
      return function () {
        _this.reducers = Object.entries(_this.reducers).filter(function (reducer) {
          return !Object.keys(newReducers).includes(reducer);
        }).reduce(function (acc, _ref) {
          var _ref2 = (0, _slicedToArray2["default"])(_ref, 2),
              key = _ref2[0],
              val = _ref2[1];

          return _objectSpread(_objectSpread({}, acc), {}, (0, _defineProperty2["default"])({}, key, val));
        }, {});

        _this.store.replaceReducer((0, _redux.combineReducers)(_objectSpread({}, _this.reducers)));
      };
    }
  }]);
  return ReducerRegistry;
}();

exports.ReducerRegistry = ReducerRegistry;
var reduxRegistry = new ReducerRegistry();
exports.reduxRegistry = reduxRegistry;
var _default = ReducerRegistry;
exports["default"] = _default;
